@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseWidgetContainer.php 3842 2010-11-19 08:26:26Z fishbone $
+ * @version    SVN: $Id: baseWidgetContainer.php 3916 2011-01-01 02:53:34Z fishbone $
  * @link       http://www.magic3.org
  */
 // テンプレートライブラリ読み込み
@@ -1235,12 +1235,13 @@ class BaseWidgetContainer extends Core
 		}
 		$time = $time / 60; // minutes
 
-		for ($i = 0; $i < count($units); $i++){
+		for ($i = 0; $i < count($values); $i++){
 			$value = $values[$i];
+			$unit = $unitArray[$i];
 			if ($time < $value) break;
 			$time /= $value;
 		}
-		$time = floor($time) . $unitArray[$i];
+		$time = floor($time) . $unit;		// 単位を付加
 		return $time;
 	}
 	/**
