@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 3808 2010-11-12 06:31:15Z fishbone $
+ * @version    SVN: $Id: envManager.php 3923 2011-01-05 07:07:02Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/version.php');	// システムバージョンクラス
@@ -39,6 +39,7 @@ class EnvManager extends Core
 	private $defaultLocale;		// デフォルトのロケール
 	private $currentLocale;		// 現在のロケール(ユーザによって可変)
 	private $multiLanguage;		// 多言語対応かどうか
+	private $adminDefaultTheme;	// 管理画面のデフォルトテーマ
 	private $accessPath;		// アクセスポイントパス
  	private $db;				// DBオブジェクト
 	private $canUseDbSession;	// DBセッションが使用できるかどうか
@@ -71,6 +72,7 @@ class EnvManager extends Core
 	const MULTI_LANGUAGE = 'multi_language';		// 多言語対応かどうか
 	const MOBILE_ENCODING = 'mobile_encoding';		// 携帯用入出力エンコーディング
 	const MOBILE_CHARSET = 'mobile_charset';		// 携帯用HTML上のエンコーディング表記
+	const DEFAULT_THEME_CSS_FILE = 'jquery-ui.custom.css';		// テーマファイル
 	const CONFIG_ID_WORK_DIR = 'work_dir';			// 作業用ディレクトリ
 	const DEFAULT_PAGE_ID = 'index';					// デフォルトのページID
 	const DEFAULT_REGIST_PAGE_ID = 'regist';		// デフォルトの登録機能用ページID
@@ -179,29 +181,15 @@ class EnvManager extends Core
 		if ($reloadFromDb) $this->gSystem->_loadSystemConfig();
 		
 		// デフォルト値取得
-/*		$this->defaultLanguage = $this->db->getDefaultLanguage();
-		$this->currentLanguage = $this->defaultLanguage;
-		$this->canChangeLang = $this->db->getCanChangeLang();// 言語変更可能かどうか
-		*/
 		$this->defaultLanguage = $this->gSystem->getSystemConfig(self::CF_DEFAULT_LANG);// デフォルト言語
 		$this->defaultLocale = $this->defaultLacaleArray[$this->defaultLanguage];		// デフォルトのロケール
 		if (empty($this->defaultLocale)) $this->defaultLocale = self::DEFAULT_LOCALE;
 		$this->currentLanguage = $this->defaultLanguage;
 		$this->currentLocale = $this->defaultLocale;			// 現在のロケール
 		$this->canChangeLang = $this->gSystem->canChangeLang();// 言語変更可能かどうか
-
-/*
-		$this->multiLanguage = $this->db->getSystemConfig(self::MULTI_LANGUAGE);		// 多言語対応かどうか
-		$this->useSsl = $this->db->getSystemConfig(self::CF_USE_SSL);		// SSL機能を使用するかどうか
-		$this->useSslAdmin = $this->db->getSystemConfig(self::CF_USE_SSL_ADMIN);		// 管理画面にSSL機能を使用するかどうか
-		$this->mobileEncoding = $this->db->getSystemConfig(self::MOBILE_ENCODING);	// 携帯用の入力、出力エンコーディング
-		$this->mobileCharset = $this->db->getSystemConfig(self::MOBILE_CHARSET);		// 携帯用HTML上のエンコーディング表記
-		$this->mobileUseSession = $this->db->getSystemConfig(self::CF_MOBILE_USE_SESSION);	// 携帯でセッション管理を使用するかどうか
-		$value = $this->db->getSystemConfig(self::CONFIG_ID_WORK_DIR);// 作業用ディレクトリ
-		if (!empty($value)) $this->workDir = $value;
-*/
-		
 		$this->multiLanguage = $this->gSystem->getSystemConfig(self::MULTI_LANGUAGE);		// 多言語対応かどうか
+		
+		$this->adminDefaultTheme = $this->gSystem->adminDefaultTheme();	// 管理画面のデフォルトテーマ
 		$this->useSsl = $this->gSystem->getSystemConfig(self::CF_USE_SSL);		// SSL機能を使用するかどうか
 		$this->useSslAdmin = $this->gSystem->getSystemConfig(self::CF_USE_SSL_ADMIN);		// 管理画面にSSL機能を使用するかどうか
 		$this->sslUrl = $this->gSystem->getSystemConfig(self::CF_SSL_URL);			// SSL用URL
@@ -497,6 +485,15 @@ class EnvManager extends Core
 	{
 		return $this->getSslRootUrl() . '/templates';
 	}
+	/**
+	 * themesディレクトリ(jQueryUIテーマディレクトリ)へのURLを取得
+	 *
+	 * 例) http://www.magic3.org/magic3/ui/themes
+	 */
+	public function getThemesUrl()
+	{
+		return M3_SYSTEM_ROOT_URL . '/ui/themes';
+	}
 	/**
 	 * 管理用ディレクトリへのパスを取得
 	 */
@@ -550,6 +547,16 @@ class EnvManager extends Core
 	{
 		return $this->getAdminUrl() . '/' . M3_FILENAME_INDEX;
 	}
+	/**
+	 * 管理画面用jQueryUIテーマのCSSのURLを取得
+	 *
+	 * @return string		CSSのURL
+	 */
+	public function getAdminDefaultThemeUrl()
+	{
+		$themeFile = $this->getThemesUrl() . '/'. $this->adminDefaultTheme . '/'. self::DEFAULT_THEME_CSS_FILE;	// 管理画面用jQueryUIテーマ
+		return $themeFile;
+	}
 	/**
 	 * 作業用ディレクトリへのパスを取得
 	 */
