@@ -1,6 +1,6 @@
 <?php
 /**
- * @version		$Id: factory.php 1971 2009-06-06 08:26:57Z fishbone $
+ * @version		$Id: factory.php 2902 2010-03-07 06:27:19Z fishbone $
  * @package		Joomla.Framework
  * @copyright	Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
  * @license		GNU/GPL, see LICENSE.php
@@ -186,6 +186,11 @@ class JFactory
 	 */
 	function &getCache($group = '', $handler = 'callback', $storage = null)
 	{
+		global $gEnvManager;
+
+		// JCacheクラスを読み込む
+		require_once($gEnvManager->getJoomlaRootPath() . '/class/cache.php');
+	
 		$handler = ($handler == 'function') ? 'callback' : $handler;
 
 		$conf =& JFactory::getConfig();
@@ -202,8 +207,6 @@ class JFactory
 			'storage'		=> $storage
 		);
 
-//		jimport('joomla.cache.cache');
-
 		$cache =& JCache::getInstance( $handler, $options );
 		$cache->setCaching($conf->getValue('config.caching'));
 		return $cache;
@@ -415,11 +418,14 @@ class JFactory
 	 */
 	function &getDate($time = 'now', $tzOffset = 0)
 	{
-//		jimport('joomla.utilities.date');
+		global $gEnvManager;
 		static $instances;
 		static $classname;
 		static $mainLocale;
 
+		// JDateクラスを読み込む
+		require_once($gEnvManager->getJoomlaRootPath() . '/class/date.php');
+
 		if(!isset($instances)) {
 			$instances = array();
 		}
@@ -429,7 +435,7 @@ class JFactory
 
 		if(!isset($classname) || $locale != $mainLocale) {
 			//Store the locale for future reference
-			$mainLocale = $locale;
+			/*$mainLocale = $locale;
 			$localePath = JPATH_ROOT . DS . 'language' . DS . $mainLocale . DS . $mainLocale . '.date.php';
 			if($mainLocale !== false && file_exists($localePath)) {
 				$classname = 'JDate'.str_replace('-', '_', $mainLocale);
@@ -438,10 +444,10 @@ class JFactory
 					//Something went wrong.  The file exists, but the class does not, default to JDate
 					$classname = 'JDate';
 				}
-			} else {
+			} else {*/
 				//No file, so default to JDate
 				$classname = 'JDate';
-			}
+			//}
 		}
 		$key = $time . '-' . $tzOffset;
 
@@ -546,9 +552,11 @@ class JFactory
 	 */
 	function &_createDBO()
 	{
-//		jimport('joomla.database.database');
-//		jimport( 'joomla.database.table' );
+		global $gEnvManager;
 
+		// JDatabaseクラスを読み込む
+		require_once($gEnvManager->getJoomlaRootPath() . '/class/database.php');
+		
 		$conf =& JFactory::getConfig();
 
 		$host 		= $conf->getValue('config.host');
@@ -678,7 +686,10 @@ class JFactory
 	 */
 	function &_createLanguage()
 	{
-//		jimport('joomla.language.language');
+		global $gEnvManager;
+
+		// JLanguageクラスを読み込む
+		require_once($gEnvManager->getJoomlaRootPath() . '/class/language.php');
 
 		$conf	=& JFactory::getConfig();
 		$locale	= $conf->getValue('config.language');
@@ -697,7 +708,10 @@ class JFactory
 	 */
 	function &_createDocument()
 	{
-//		jimport('joomla.document.document');
+		global $gEnvManager;
+
+		// JDocumentクラスを読み込む
+		require_once($gEnvManager->getJoomlaRootPath() . '/class/document.php');
 
 		$lang	=& JFactory::getLanguage();
 
