@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_analyzeDb.php 3750 2010-10-28 17:36:26Z fishbone $
+ * @version    SVN: $Id: admin_analyzeDb.php 3878 2010-12-04 02:14:23Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -239,35 +239,42 @@ class admin_analyzeDb extends BaseDb
 		$queryStr .=  'GROUP BY al_path ';
 		$queryStr .=  'ORDER BY total DESC';
 		$ret = $this->selectRecords($queryStr, $params, $rows);
-	
+
 		// 集計データを登録
 		if ($ret){			// データありのとき
 			for ($j = 0; $j < count($rows); $j++){
 				$total = $rows[$j]["total"];
 				$path = $rows[$j]["al_path"];
 
-				$queryStr  = 'INSERT INTO _analyze_daily_count (';
-				$queryStr .=   'aa_type, ';
-				$queryStr .=   'aa_url, ';
-				$queryStr .=   'aa_date, ';
-				$queryStr .=   'aa_count, ';
-				$queryStr .=   'aa_path ';
-				$queryStr .= ') VALUES (';
-				$queryStr .=   '?, ?, ?, ?, ?';
-				$queryStr .= ')';
-				$ret = $this->execStatement($queryStr, array(0/*訪問数*/, ''/*アクセスポイント指定*/, $date, $total, $path));
-				if (!$ret) return false;	// エラー発生
+				// FCKEditorからのアクセスは、アクセスポイントを使用しないので除く
+				if (!empty($path)){
+					$queryStr  = 'INSERT INTO _analyze_daily_count (';
+					$queryStr .=   'aa_type, ';
+					$queryStr .=   'aa_url, ';
+					$queryStr .=   'aa_date, ';
+					$queryStr .=   'aa_count, ';
+					$queryStr .=   'aa_path ';
+					$queryStr .= ') VALUES (';
+					$queryStr .=   '?, ?, ?, ?, ?';
+					$queryStr .= ')';
+					$ret = $this->execStatement($queryStr, array(0/*訪問数*/, ''/*アクセスポイント指定*/, $date, $total, $path));
+					if (!$ret) return false;	// エラー発生
+				}
 			}
 		}
 		// 一日あたりすべてのアクセスポイントの集計
+		// MySQL v5.0.22でエラー発生(2010/12/3)
+		// SQLエラーメッセージ(Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns is illegal if there is no GROUP BY clause error code: 42000)
+		// 「GROUP BY」を付けると回避可能
 		$params = array();
-		$queryStr  = 'SELECT COUNT(DISTINCT al_session) AS total,al_uri,al_path FROM _access_log ';
+		//$queryStr  = 'SELECT COUNT(DISTINCT al_session) AS total,al_uri,al_path FROM _access_log ';		// NG
+		$queryStr  = 'SELECT COUNT(DISTINCT al_session) AS total FROM _access_log ';		// OK
 		$queryStr .=   'WHERE (? <= al_dt AND al_dt < ?) ';
 		$params[] = $startDt;
 		$params[] = $endDt;
 		$queryStr .=  'ORDER BY total DESC';
 		$ret = $this->selectRecord($queryStr, $params, $row);
-	
+
 		// 集計データを登録
 		if ($ret && $row["total"] > 0){			// データありのとき
 			$total = $row["total"];
@@ -352,30 +359,34 @@ class admin_analyzeDb extends BaseDb
 		$queryStr .=  'GROUP BY al_path ';
 		$queryStr .=  'ORDER BY total DESC';
 		$ret = $this->selectRecords($queryStr, $params, $rows);
-	
+
 		// 集計データを登録
 		if ($ret){			// データありのとき
 			for ($j = 0; $j < count($rows); $j++){
 				$total = $rows[$j]["total"];
 				$path = $rows[$j]["al_path"];
 
-				$queryStr  = 'INSERT INTO _analyze_daily_count (';
-				$queryStr .=   'aa_type, ';
-				$queryStr .=   'aa_url, ';
-				$queryStr .=   'aa_date, ';
-				$queryStr .=   'aa_count, ';
-				$queryStr .=   'aa_path ';
-				$queryStr .= ') VALUES (';
-				$queryStr .=   '?, ?, ?, ?, ?';
-				$queryStr .= ')';
-				$ret = $this->execStatement($queryStr, array(1/*訪問者数*/, ''/*アクセスポイント指定*/, $date, $total, $path));
-				if (!$ret) return false;	// エラー発生
+				// FCKEditorからのアクセスは、アクセスポイントを使用しないので除く
+				if (!empty($path)){
+					$queryStr  = 'INSERT INTO _analyze_daily_count (';
+					$queryStr .=   'aa_type, ';
+					$queryStr .=   'aa_url, ';
+					$queryStr .=   'aa_date, ';
+					$queryStr .=   'aa_count, ';
+					$queryStr .=   'aa_path ';
+					$queryStr .= ') VALUES (';
+					$queryStr .=   '?, ?, ?, ?, ?';
+					$queryStr .= ')';
+					$ret = $this->execStatement($queryStr, array(1/*訪問者数*/, ''/*アクセスポイント指定*/, $date, $total, $path));
+					if (!$ret) return false;	// エラー発生
+				}
 			}
 		}
 		
 		// 1日あたりすべてのアクセスの集計
 		$params = array();
-		$queryStr  = 'SELECT COUNT(DISTINCT al_cookie_value) AS total,al_uri,al_path FROM _access_log ';
+		//$queryStr  = 'SELECT COUNT(DISTINCT al_cookie_value) AS total,al_uri,al_path FROM _access_log ';		// NG
+		$queryStr  = 'SELECT COUNT(DISTINCT al_cookie_value) AS total FROM _access_log ';		// OK
 		$queryStr .=   'WHERE (? <= al_dt AND al_dt < ?) ';
 		$params[] = $startDt;
 		$params[] = $endDt;
