@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: nav_menu_cssWidgetContainer.php 2266 2009-08-28 08:25:59Z fishbone $
+ * @version    SVN: $Id: nav_menu_cssWidgetContainer.php 2363 2009-09-26 14:45:44Z fishbone $
  * @link       http://www.magic3.org
  * @CSS対応化に改造　Yu Fujiwara <n_akira@hotmail.com> 2008-11-19
  */
@@ -85,10 +85,9 @@ class nav_menu_cssWidgetContainer extends BaseWidgetContainer
 	function _assign($request, &$param)
 	{
 		global $gEnvManager;
-		global $gDesignManager;
 		
 		// メニューテーブルのパラメータ
-		//$this->tmpl->addVar("_widget", "default_menu_param", $gDesignManager->getDefaultWidgetTableParam());
+		//$this->tmpl->addVar("_widget", "default_menu_param", $this->gDesign->getDefaultWidgetTableParam());
 		
 		// メインメニューの項目取得
 		// 現在の言語で作成
